@@ -11,6 +11,7 @@ from django.utils.html import escape
 
 import core_main_app.components.data.api as data_api
 import core_main_app.components.user.api as user_api
+import core_main_app.components.template.api as template_api
 from core_dashboard_common_app import constants
 from core_main_app.access_control.exceptions import AccessControlError
 from core_main_app.commons.exceptions import DoesNotExist
@@ -357,7 +358,7 @@ def _change_owner_form(request, form_ids, user_id):
 
     Args:
         request:
-        data_ids:
+        form_ids:
         user_id:
 
     Returns:
@@ -368,9 +369,9 @@ def _change_owner_form(request, form_ids, user_id):
         return HttpResponseBadRequest(escape(str(e)))
 
     try:
+        new_user = user_api.get_user_by_id(user_id)
         for form in list_form:
-            form.user = user_id
-            curate_data_structure_api.upsert(form, request.user)
+            curate_data_structure_api.change_owner(form, new_user, request.user)
     except Exception as e:
         return HttpResponseBadRequest(escape(str(e)))
 
@@ -463,10 +464,11 @@ def edit_record(request):
             data.id, request.user
         )
     except DoesNotExist:
+        template = template_api.get(str(data.template.id), request=request)
         # Create a new curate data structure
         curate_data_structure = CurateDataStructure(
             user=str(request.user.id),
-            template=str(data.template.id),
+            template=str(template.id),
             name=data.title,
             form_string=data.xml_content,
             data=data,
